core library
Stable compatibility export for Dart-only Dust functional primitives.
Classes
-
Err<
T, E> - Failed operation result.
-
None<
T> - Option state for an absent value.
-
Ok<
T, E> - Successful operation result.
-
Option<
T> - Optional value wrapper for Rust-style present-or-absent values.
-
Result<
T, E> -
Result of an operation that can either succeed with
Tor fail withE. -
Some<
T> - Option state for a present value.
- Unit
- Empty success value for operations that only signal completion.
Extensions
-
OptionCombine
on Option<
T> - Combining Option values, and moving between Option and Result.
-
OptionFlatten
on Option<
Option< T> > - Removing one level of Option nesting.
-
OptionQuery
on Option<
T> - Reading an Option without matching on it.
-
OptionTransform
on Option<
T> - Transforming and choosing between Option values.
-
OptionTranspose
on Option<
Result< T, E> > - Swapping an Option of a Result inside out.
-
OptionUnzip
on Option<
(A, B)> - Splitting an Option of a pair.