FromRow class final
Derive trait for a class that Dust can construct from one database row.
- Inheritance
-
- Object
- DeriveMeta
- DeriveTrait
- FromRow
Constructors
- FromRow()
-
Creates the
FromRowderive marker.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited