HttpMethod class abstract

Base class for HTTP method annotations.

Implementers
Annotations
  • @immutable

Constructors

HttpMethod(String path)
Creates one HTTP method annotation.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
path → String
Method path template relative to the client base URL.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited