HttpParseThread enum

Defines the thread context for JSON parsing.

Inheritance
Available extensions

Values

main → const HttpParseThread

Decoding happens on the thread that initiated the request.

isolate → const HttpParseThread

Decoding is offloaded to a background isolate.

Dart-targeted clients use Isolate.run; Flutter-targeted clients use Flutter's compute helper.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<HttpParseThread>
A constant List of the values in this enum, in order of their declaration.