HttpTarget enum

Defines the runtime target for generated HTTP clients.

Inheritance
Available extensions

Values

dart → const HttpTarget

Generate runtime behavior that works in pure Dart environments.

flutter → const HttpTarget

Generate runtime behavior intended for Flutter applications.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<HttpTarget>
A constant List of the values in this enum, in order of their declaration.