Validatable class abstract interface

Runtime contract implemented by generated Validate() mixins.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate() ValidationResult
Validates this value and returns all validation errors.
validateOrThrow() → void
Throws ValidationException when this value is invalid.

Operators

operator ==(Object other) bool
The equality operator.
inherited