ValidationHelper class abstract final

Shared helpers used by generated validation code.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

isEmail(String value) bool
Returns true when value uses a basic email format.
isUrl(String value) bool
Returns true when value is an absolute URL with scheme and host.