Backwards-compatible long-lived database pool name.
- Implemented types
Properties
- driver → Driver
-
Database driver used by this executor.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- raw → RawSql
-
Explicit unchecked SQL access for dynamic/admin queries.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → Future< Result< Unit, SqlxError> > -
Closes resources owned by this driver.
inherited
-
execute(
String sql, List< Object?> parameters) → Future<Result< ExecResult, SqlxError> > -
Runs a checked statement and returns execution metadata.
inherited
-
fetchAll<
T> (String sql, List< Object?> parameters, RowMapper<T> mapper) → Future<Result< List< >T> , SqlxError> -
Runs a checked row query that returns all rows.
inherited
-
fetchOne<
T> (String sql, List< Object?> parameters, RowMapper<T> mapper) → Future<Result< T, SqlxError> > -
Runs a checked row query that must return exactly one row.
inherited
-
fetchOptional<
T> (String sql, List< Object?> parameters, RowMapper<T> mapper) → Future<Result< T?, SqlxError> > -
Runs a checked row query that returns zero or one row.
inherited
-
fetchScalar<
T> (String sql, List< Object?> parameters) → Future<Result< T, SqlxError> > -
Runs a checked scalar query and reads column index zero.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
transaction<
T> (Future< Result< fn(Executor tx)) → Future<T, SqlxError> >Result< T, SqlxError> > -
Runs
fninside a database transaction.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited